pub struct EndpointInterest {
pub topic_code: TopicCode,
pub endpoint: EndpointAddr,
pub interests: Vec<Interest>,
}Fields
topic_code: TopicCodeendpoint: EndpointAddrinterests: Vec<Interest>Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for EndpointInterest
impl<'__de, __Context> BorrowDecode<'__de, __Context> for EndpointInterest
Sourcefn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<EndpointInterest, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<EndpointInterest, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for EndpointInterest
impl Clone for EndpointInterest
Sourcefn clone(&self) -> EndpointInterest
fn clone(&self) -> EndpointInterest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointInterest
impl Debug for EndpointInterest
Sourceimpl<__Context> Decode<__Context> for EndpointInterest
impl<__Context> Decode<__Context> for EndpointInterest
Sourcefn decode<__D>(decoder: &mut __D) -> Result<EndpointInterest, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(decoder: &mut __D) -> Result<EndpointInterest, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
Sourceimpl<'de> Deserialize<'de> for EndpointInterest
impl<'de> Deserialize<'de> for EndpointInterest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<EndpointInterest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<EndpointInterest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for EndpointInterest
impl Encode for EndpointInterest
Sourceimpl Serialize for EndpointInterest
impl Serialize for EndpointInterest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more