pub struct StateMachineStore {
pub state_machine: RwLock<StateMachineData<TypeConfig>>,
/* private fields */
}Expand description
Defines a state machine for the Raft cluster. This state machine represents a copy of the data for this node. Additionally, it is responsible for storing the last snapshot of the data.
Fields
state_machine: RwLock<StateMachineData<TypeConfig>>The Raft state machine.
Implementations