pub struct TypeConfig { /* private fields */ }Trait Implementations
Sourceimpl Clone for TypeConfig
impl Clone for TypeConfig
Sourcefn clone(&self) -> TypeConfig
fn clone(&self) -> TypeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TypeConfig
Sourceimpl Debug for TypeConfig
impl Debug for TypeConfig
Sourceimpl Default for TypeConfig
impl Default for TypeConfig
Sourcefn default() -> TypeConfig
fn default() -> TypeConfig
Returns the “default value” for a type. Read more
impl Eq for TypeConfig
Sourceimpl Ord for TypeConfig
impl Ord for TypeConfig
Sourcefn cmp(&self, other: &TypeConfig) -> Ordering
fn cmp(&self, other: &TypeConfig) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TypeConfig
impl PartialEq for TypeConfig
Sourcefn eq(&self, other: &TypeConfig) -> bool
fn eq(&self, other: &TypeConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TypeConfig
impl PartialOrd for TypeConfig
Sourceimpl RaftLogReader<TypeConfig> for LogStorage<TypeConfig>
impl RaftLogReader<TypeConfig> for LogStorage<TypeConfig>
Sourceasync fn try_get_log_entries<RB: RangeBounds<u64> + Clone + Debug + OptionalSend>(
&mut self,
range: RB,
) -> Result<Vec<<TypeConfig as RaftTypeConfig>::Entry>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn try_get_log_entries<RB: RangeBounds<u64> + Clone + Debug + OptionalSend>( &mut self, range: RB, ) -> Result<Vec<<TypeConfig as RaftTypeConfig>::Entry>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Get a series of log entries from storage. Read more
Sourcefn limited_get_log_entries(
&mut self,
start: u64,
end: u64,
) -> impl Future<Output = Result<Vec<<C as RaftTypeConfig>::Entry>, StorageError<<C as RaftTypeConfig>::NodeId>>> + Send
fn limited_get_log_entries( &mut self, start: u64, end: u64, ) -> impl Future<Output = Result<Vec<<C as RaftTypeConfig>::Entry>, StorageError<<C as RaftTypeConfig>::NodeId>>> + Send
Returns log entries within range
[start, end), end is exclusive,
potentially limited by implementation-defined constraints. Read moreSourceimpl RaftLogStorage<TypeConfig> for LogStorage<TypeConfig>
impl RaftLogStorage<TypeConfig> for LogStorage<TypeConfig>
Sourcetype LogReader = LogStorage
type LogReader = LogStorage
Log reader type. Read more
Sourceasync fn append<I>(
&mut self,
entries: I,
callback: LogFlushed<TypeConfig>,
) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>where
I: IntoIterator<Item = <TypeConfig as RaftTypeConfig>::Entry> + OptionalSend,
I::IntoIter: OptionalSend,
async fn append<I>(
&mut self,
entries: I,
callback: LogFlushed<TypeConfig>,
) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>where
I: IntoIterator<Item = <TypeConfig as RaftTypeConfig>::Entry> + OptionalSend,
I::IntoIter: OptionalSend,
Append log entries and call the
callback once logs are persisted on disk. Read moreSourceasync fn get_log_reader(&mut self) -> Self::LogReader
async fn get_log_reader(&mut self) -> Self::LogReader
Get the log reader. Read more
Sourceasync fn get_log_state(
&mut self,
) -> Result<LogState<TypeConfig>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn get_log_state( &mut self, ) -> Result<LogState<TypeConfig>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Returns the last deleted log id and the last log id. Read more
Sourceasync fn purge(
&mut self,
log_id: LogId<<TypeConfig as RaftTypeConfig>::NodeId>,
) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn purge( &mut self, log_id: LogId<<TypeConfig as RaftTypeConfig>::NodeId>, ) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Purge logs upto
log_id, inclusive Read moreSourceasync fn read_committed(
&mut self,
) -> Result<Option<LogId<<TypeConfig as RaftTypeConfig>::NodeId>>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn read_committed( &mut self, ) -> Result<Option<LogId<<TypeConfig as RaftTypeConfig>::NodeId>>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Return the last saved committed log id by
Self::save_committed.Sourceasync fn save_committed(
&mut self,
committed: Option<LogId<<TypeConfig as RaftTypeConfig>::NodeId>>,
) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn save_committed( &mut self, committed: Option<LogId<<TypeConfig as RaftTypeConfig>::NodeId>>, ) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Saves the last committed log id to storage. Read more
Sourceasync fn read_vote(
&mut self,
) -> Result<Option<Vote<<TypeConfig as RaftTypeConfig>::NodeId>>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn read_vote( &mut self, ) -> Result<Option<Vote<<TypeConfig as RaftTypeConfig>::NodeId>>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Return the last saved vote by
Self::save_vote.Sourceasync fn save_vote(
&mut self,
vote: &Vote<<TypeConfig as RaftTypeConfig>::NodeId>,
) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn save_vote( &mut self, vote: &Vote<<TypeConfig as RaftTypeConfig>::NodeId>, ) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Save vote to storage. Read more
Sourceasync fn truncate(
&mut self,
log_id: LogId<<TypeConfig as RaftTypeConfig>::NodeId>,
) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn truncate( &mut self, log_id: LogId<<TypeConfig as RaftTypeConfig>::NodeId>, ) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Truncate logs since
log_id, inclusive Read moreSourceimpl RaftNetwork<TypeConfig> for TcpNetwork
impl RaftNetwork<TypeConfig> for TcpNetwork
Sourceasync fn vote(
&mut self,
rpc: VoteRequest<<TypeConfig as RaftTypeConfig>::NodeId>,
_option: RPCOption,
) -> Result<VoteResponse<<TypeConfig as RaftTypeConfig>::NodeId>, RPCError<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node, RaftError<<TypeConfig as RaftTypeConfig>::NodeId>>>
async fn vote( &mut self, rpc: VoteRequest<<TypeConfig as RaftTypeConfig>::NodeId>, _option: RPCOption, ) -> Result<VoteResponse<<TypeConfig as RaftTypeConfig>::NodeId>, RPCError<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node, RaftError<<TypeConfig as RaftTypeConfig>::NodeId>>>
Send a RequestVote RPC to the target.
Sourceasync fn append_entries(
&mut self,
rpc: AppendEntriesRequest<TypeConfig>,
_option: RPCOption,
) -> Result<AppendEntriesResponse<<TypeConfig as RaftTypeConfig>::NodeId>, RPCError<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node, RaftError<<TypeConfig as RaftTypeConfig>::NodeId>>>
async fn append_entries( &mut self, rpc: AppendEntriesRequest<TypeConfig>, _option: RPCOption, ) -> Result<AppendEntriesResponse<<TypeConfig as RaftTypeConfig>::NodeId>, RPCError<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node, RaftError<<TypeConfig as RaftTypeConfig>::NodeId>>>
Send an AppendEntries RPC to the target.
Sourceasync fn install_snapshot(
&mut self,
rpc: InstallSnapshotRequest<TypeConfig>,
_option: RPCOption,
) -> Result<InstallSnapshotResponse<<TypeConfig as RaftTypeConfig>::NodeId>, RPCError<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node, RaftError<<TypeConfig as RaftTypeConfig>::NodeId, InstallSnapshotError>>>
async fn install_snapshot( &mut self, rpc: InstallSnapshotRequest<TypeConfig>, _option: RPCOption, ) -> Result<InstallSnapshotResponse<<TypeConfig as RaftTypeConfig>::NodeId>, RPCError<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node, RaftError<<TypeConfig as RaftTypeConfig>::NodeId, InstallSnapshotError>>>
Send an InstallSnapshot RPC to the target.
Sourcefn full_snapshot(
&mut self,
vote: Vote<<C as RaftTypeConfig>::NodeId>,
snapshot: Snapshot<C>,
cancel: impl Future<Output = ReplicationClosed> + OptionalSend + 'static,
option: RPCOption,
) -> impl Future<Output = Result<SnapshotResponse<<C as RaftTypeConfig>::NodeId>, StreamingError<C, Fatal<<C as RaftTypeConfig>::NodeId>>>> + Send
fn full_snapshot( &mut self, vote: Vote<<C as RaftTypeConfig>::NodeId>, snapshot: Snapshot<C>, cancel: impl Future<Output = ReplicationClosed> + OptionalSend + 'static, option: RPCOption, ) -> impl Future<Output = Result<SnapshotResponse<<C as RaftTypeConfig>::NodeId>, StreamingError<C, Fatal<<C as RaftTypeConfig>::NodeId>>>> + Send
Send a complete Snapshot to the target. Read more
Sourceimpl RaftNetworkFactory<TypeConfig> for TcpNetworkService
impl RaftNetworkFactory<TypeConfig> for TcpNetworkService
Sourcetype Network = TcpNetwork
type Network = TcpNetwork
Actual type of the network handling a single connection.
Sourceasync fn new_client(
&mut self,
target: <TypeConfig as RaftTypeConfig>::NodeId,
node: &<TypeConfig as RaftTypeConfig>::Node,
) -> Self::Network
async fn new_client( &mut self, target: <TypeConfig as RaftTypeConfig>::NodeId, node: &<TypeConfig as RaftTypeConfig>::Node, ) -> Self::Network
Create a new network instance sending RPCs to the target node. Read more
Sourceimpl RaftSnapshotBuilder<TypeConfig> for Arc<StateMachineStore>
impl RaftSnapshotBuilder<TypeConfig> for Arc<StateMachineStore>
Sourceasync fn build_snapshot(
&mut self,
) -> Result<Snapshot<TypeConfig>, StorageError<NodeId>>
async fn build_snapshot( &mut self, ) -> Result<Snapshot<TypeConfig>, StorageError<NodeId>>
Build snapshot Read more
Sourceimpl RaftStateMachine<TypeConfig> for Arc<StateMachineStore>
impl RaftStateMachine<TypeConfig> for Arc<StateMachineStore>
Sourcetype SnapshotBuilder = Arc<StateMachineStore>
type SnapshotBuilder = Arc<StateMachineStore>
Snapshot builder type.
Sourceasync fn applied_state(
&mut self,
) -> Result<(Option<LogId<<TypeConfig as RaftTypeConfig>::NodeId>>, StoredMembership<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node>), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn applied_state( &mut self, ) -> Result<(Option<LogId<<TypeConfig as RaftTypeConfig>::NodeId>>, StoredMembership<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node>), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Returns the last applied log id which is recorded in state machine, and the last applied
membership config. Read more
Sourceasync fn apply<I>(
&mut self,
entries: I,
) -> Result<Vec<<TypeConfig as RaftTypeConfig>::R>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>where
I: IntoIterator<Item = <TypeConfig as RaftTypeConfig>::Entry> + OptionalSend,
I::IntoIter: OptionalSend,
async fn apply<I>(
&mut self,
entries: I,
) -> Result<Vec<<TypeConfig as RaftTypeConfig>::R>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>where
I: IntoIterator<Item = <TypeConfig as RaftTypeConfig>::Entry> + OptionalSend,
I::IntoIter: OptionalSend,
Apply the given payload of entries to the state machine. Read more
Sourceasync fn begin_receiving_snapshot(
&mut self,
) -> Result<Box<<TypeConfig as RaftTypeConfig>::SnapshotData>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn begin_receiving_snapshot( &mut self, ) -> Result<Box<<TypeConfig as RaftTypeConfig>::SnapshotData>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Create a new blank snapshot, returning a writable handle to the snapshot object. Read more
Sourceasync fn get_current_snapshot(
&mut self,
) -> Result<Option<Snapshot<TypeConfig>>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn get_current_snapshot( &mut self, ) -> Result<Option<Snapshot<TypeConfig>>, StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Get a readable handle to the current snapshot. Read more
Sourceasync fn get_snapshot_builder(&mut self) -> Self::SnapshotBuilder
async fn get_snapshot_builder(&mut self) -> Self::SnapshotBuilder
Get the snapshot builder for the state machine. Read more
Sourceasync fn install_snapshot(
&mut self,
meta: &SnapshotMeta<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node>,
snapshot: Box<<TypeConfig as RaftTypeConfig>::SnapshotData>,
) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
async fn install_snapshot( &mut self, meta: &SnapshotMeta<<TypeConfig as RaftTypeConfig>::NodeId, <TypeConfig as RaftTypeConfig>::Node>, snapshot: Box<<TypeConfig as RaftTypeConfig>::SnapshotData>, ) -> Result<(), StorageError<<TypeConfig as RaftTypeConfig>::NodeId>>
Install a snapshot which has finished streaming from the leader. Read more
Sourceimpl RaftTypeConfig for TypeConfig
impl RaftTypeConfig for TypeConfig
Sourcetype R = RaftResponse
type R = RaftResponse
Application-specific response data returned by the state machine.
Sourcetype Entry = Entry<TypeConfig>
type Entry = Entry<TypeConfig>
Raft log entry, which can be built from an AppData.
Sourcetype SnapshotData = Cursor<Vec<u8>>
type SnapshotData = Cursor<Vec<u8>>
Snapshot data for exposing a snapshot for reading & writing. Read more
Sourcetype AsyncRuntime = TokioRuntime
type AsyncRuntime = TokioRuntime
Asynchronous runtime type.
Sourcetype Responder = OneshotResponder<TypeConfig>
type Responder = OneshotResponder<TypeConfig>
Send the response or error of a client write request(
WriteResult). Read moreimpl StructuralPartialEq for TypeConfig